﻿using UnityEngine;
using System.Reflection;
using HarmonyLib;

public class LongerTravels : Mod
{
    private const string logPrefix = "[<color=#0000ff>Longer Travels</color>] ";
    private Harmony harmonyInstance;
    private string harmonyId = "com.nundir.longertravels";

    public void Start()
    {
        harmonyInstance = new Harmony(harmonyId);
        harmonyInstance.PatchAll(Assembly.GetExecutingAssembly());

        Debug.Log(logPrefix + "Longer Travels loaded!");
    }

    public void OnModUnload()
    {
        harmonyInstance.UnpatchAll(harmonyId);
        Debug.Log(logPrefix + "Longer Travels unloaded!");
    }
}

[HarmonyPatch(typeof(ChunkManager))]
[HarmonyPatch("Awake")]
class Patch_ChunkManager_Awake
{
	[HarmonyPostfix]
	static void Postfix(ref ChunkManager __instance)
	{
        // Read private value
        SO_ChunkSpawnRuleAsset[] bananahammock = Traverse.Create(__instance).Field("allChunkPointRules").GetValue<SO_ChunkSpawnRuleAsset[]>();
        foreach (var banana in bananahammock)
		{
            float low = 8000f;
            float high = 10000f;
			if (banana.isFrequencyPoint)
			{
                switch (banana.ChunkPointType)
                {
                    case ChunkPointType.Landmark_RadioTower:
                        low = 4000f;
                        high = 5000f;
                        break;
                    case ChunkPointType.Landmark_Vasagatan:
                        low = 4000f;
                        high = 5000f;
                        break;
                    case ChunkPointType.Landmark_Balboa:
                        low = 4000f;
                        high = 5000f;
                        break;
                    case ChunkPointType.Landmark_CaravanIsland:
                        low = 8000f;
                        high = 10000f;
                        break;
                    case ChunkPointType.Landmark_Tangaroa:
                        low = 8000f;
                        high = 10000f;
                        break;
                    case ChunkPointType.Landmark_VarunaPoint:
                        low = 8000f;
                        high = 10000f;
                        break;
                    case ChunkPointType.Landmark_Temperance:
                        low = 8000f;
                        high = 10000f;
                        break;
                    case ChunkPointType.Landmark_Utopia:
                        low = 18000f;
                        high = 20000f;
                        break;
                    default:
                        break;
                }

                banana.SpawnDistanceFromRaft.minValue = low;
                banana.SpawnDistanceFromRaft.maxValue = high;
            }
		}

        // Write back to source
        Traverse.Create(__instance).Field("allChunkPointRules").SetValue(bananahammock);
        Debug.Log("Longer Travels executed!");
    }
}